@@ -39,10 +39,6 @@
 
 QT_BEGIN_NAMESPACE
 
-class LU {
-    Q_DECLARE_TR_FUNCTIONS(LUpdate)
-};
-
 static bool isDigitFriendly(QChar c)
 {
     return c.isPunct() || c.isSpace();
